This function creates a new instance of GGobi with or without new data. Use
this function whenever you want to create a new GGobi indepdent of the
others---they will not share linked plots. If you want to add
another dataset to an existing ggobi, please see [<-.GGobi
There are currently three basic types of functions that you
can use with rggobi:
You will generally spend most of your time working with
ggobdatas, you retrieve using $.GGobiData,
[.GGobiData, or [[.GGobiData.
Most of the time these will operate like normal R datasets while
pointing to the data in GGobi so that all changes are kept in sync.
If you need to force a ggobiDaataset to be an R data.frame use
as.data.frame.