powered by
Returns a ggobi reference
ggobi_get(id = ggobi_count(), drop=TRUE)
numeric vector indicating which ggobi instances to retrieve. Use default if none specified
drop if possible?
This allows one to get a list of all the ggobi instances currently in existence in the R session. Also, one can fetch particular instances.
# NOT RUN { ggobi(mtcars) ggobi(Nile) ggobi_get(1) ggobi_get(1:2) # }
Run the code above in your browser using DataLab