Instantiate new ggobi with a longitudinal data set.
Usage
ggobi_longitudinal(data, time=1:rows, id=rep(1, rows), g = NULL)
Arguments
data
data frame
time
time variable
id
id variable
g
ggobi instance, if you don't want to create a new one
Details
This function allows you to load longitudinal data in
to GGobi and display it as a line plot. This is achieved
by creating edges between adjacent time points, for a given
id variable.
For best viewing, we recommend that you turn the show points off
in the options menu. When brushing, you may also want to use
categorical brushing on the id variable, so that the entire
series is selected for an observation.